@@ -50,6 +50,9 @@ tar xf ${BASEDIR}/${PIPELINE}-kit-${UVERSION}/${PIPELINE}-calib-${VERSION}.tar.g
 mv ${BASEDIR}/${PIPELINE}-${VERSION}/${PIPELINE}-calib-${VERSION}/ \
    ${BASEDIR}/${PIPELINE}-${VERSION}/calib/
 if [ $INCLUDE_CALIB = "no" ] ; then
+  sha1sum -b ${BASEDIR}/${PIPELINE}-kit-${UVERSION}/${PIPELINE}-calib-${VERSION}.tar.gz\
+      | cut -d\  -f1 \
+      > ${BASEDIR}/${PIPELINE}-${VERSION}/calib/cal_shasum
   du -s ${BASEDIR}/${PIPELINE}-${VERSION}/calib/cal | cut -f1 \
       > ${BASEDIR}/${PIPELINE}-${VERSION}/calib/cal_size
   rm -rf ${BASEDIR}/${PIPELINE}-${VERSION}/calib/cal
